@@ -91,7 +91,7 @@ def cal_delta_chi(df):
 
     return df
 
-def depth_measure(wav, flux, line_input, suffix=False, S_N=False, func='parabola', del_wav_lim=0.2, plot=False):
+def depth_measure(wav, flux, line_input, suffix=False, S_N=False, func='parabola', del_wav_lim=0.2, plot=False, pixel_num=None):
     '''
     Measure the line depth of a spectrum. Provides the Gaussian, parabola and Gaussian-Hermite function for fitting the line. Require signal to noise ratio (SNR) to calculate the error of line depth; if not given, then only the fitting error will be included. There is no error estimation for Guassian-Hermite fitting now.
 
@@ -155,10 +155,11 @@ def depth_measure(wav, flux, line_input, suffix=False, S_N=False, func='parabola
         # Extract 4 or 5 (9 or 10) pixels near the line wavelength.
         ff_there = private.np.min(private.np.abs(wav - line))
         del_wav = abs(wav[private.np.argsort(private.np.abs(wav - line))[0]] - wav[private.np.argsort(private.np.abs(wav - line))[1]]) / 4
-        if func in ['parabola', 'Gauss']:
-            pixel_num = 4
-        elif func == 'GH':
-            pixel_num = 9
+        if pixel_num is None:
+            if func in ['parabola', 'Gauss']:
+                pixel_num = 4
+            elif func == 'GH':
+                pixel_num = 9
 
         if ff_there < del_wav and func != 'GH':
             sub_wav = wav[private.np.argsort(private.np.abs(wav - line))[0:pixel_num+1]]
